@@ -1,10 +1,22 @@
-;; utop.el
-;; -------
-;; Copyright : (c) 2011, Jeremie Dimino <jeremie@dimino.org>
-;; Licence   : BSD3
-;;
+;;; utop.el --- Universal toplevel for OCaml
+
+;; Copyright: (c) 2011, Jeremie Dimino <jeremie@dimino.org>
+;; Author: Jeremie Dimino <jeremie@dimino.org>
+;; URL: https://github.com/diml/utop
+;; Licence: BSD3
+;; Version: 1.11
+;; Package-Requires: ((emacs "24"))
+;; Keywords: ocaml languages
+
 ;; This file is a part of utop.
 
+;;; Commentary:
+
+;; See the README for more info;
+;; https://github.com/diml/utop
+
+;;; Code:
+
 (require 'easymenu)
 
 ;; tabulated-list is a part of Emacs 24
@@ -135,7 +147,7 @@ This hook is only run if exiting actually kills the buffer."
     (define-key map [(control ?a)] 'utop-bol)
     (define-key map [(meta ?p)] 'utop-history-goto-prev)
     (define-key map [(meta ?n)] 'utop-history-goto-next)
-    (define-key map [tab] 'utop-complete)
+    (define-key map (kbd "TAB") 'utop-complete)
     (define-key map [(control ?c) (control ?c)] 'utop-interrupt)
     (define-key map [(control ?c) (control ?i)] 'utop-interrupt)
     (define-key map [(control ?c) (control ?k)] 'utop-kill)
@@ -616,9 +628,11 @@ it is started."
      ;; End of completion
      ((string= command "completion-stop")
       (utop-set-state 'edit)
-      (with-current-buffer utop-complete-buffer
-        (with-output-to-temp-buffer "*Completions*"
-          (display-completion-list (nreverse utop-completion))))
+      (if (> (length utop-completion) 1)
+          (with-current-buffer utop-complete-buffer
+            (with-output-to-temp-buffer "*Completions*"
+              (display-completion-list (nreverse utop-completion))))
+        (minibuffer-hide-completions))
       (setq utop-completion nil)))))
 
 (defun utop-process-output (process output)
@@ -1222,3 +1236,5 @@ Special keys for utop:
   buf))
 
 (provide 'utop)
+
+;;; utop.el ends here
